import { Serial } from "syrus4-nodejs"

const _satcom_cache = {}

// Satcom
export async function getSatcom(fields, data) {
	if (_satcom_cache.value) return _satcom_cache.value
	try {
		if (!fields['$satcom']) {
			return ""
		}
		let state = await Serial.getSerialModemState()
		let is_satcom = state.type == "satcom"
		_satcom_cache.value = is_satcom ? `;II=${state.id}` : ""
		// clear cache periodically (15 mins)
		setTimeout(() => { _satcom_cache.value = null }, 1000 * 60 * 15)
		return _satcom_cache.value
	} catch (e) {
		console.error(e)
		return ""
	}
}

// IButton
export function getIB_IS(fields, data) {
	const empty = "0".repeat(16)
	try {
		let txt = "";
		let { IB, IS } = fields
		if (IB) {
			let IB_value = data[IB] || empty
			txt += `;IB=${IB_value}`
		}
		if (IS) {
			let IS_value = data[IS] || empty
			let tokens = IS.split('.')
			tokens[tokens.length - 1] = 'connected'
			let is_connected = data[tokens.join(".")] && 1 || 0
			txt += `;IS=${is_connected}${IS_value}`
		}
		return txt;
	} catch (e) {
		console.error(e)
		return ""
	}
}

// Tempearture
export function getEA(fields, data) {
	try {
		let txt = "";
		let { EA_A, EA_B, EA_C } = fields
		// if none are present, skip tag
		if (!(EA_A || EA_B || EA_C)) {
			return txt
		}
		let tokens = []
		if (EA_A && data[EA_A]) {
			tokens.push(`A${data[EA_A]}`)
		} else {
			tokens.push("A*")
		}
		if (EA_B && data[EA_B]) {
			tokens.push(`B${data[EA_B]}`)
		} else {
			tokens.push("B*")
		}
		if (EA_C && data[EA_C]) {
			tokens.push(`C${data[EA_C]}`)
		} else {
			tokens.push("C*")
		}
		txt = `;EA=${tokens.join("")}`
		return txt;
	} catch (e) {
		console.error(e)
		return ""
	}
}

// RFID
export function getRI(fields, data) {
	try {
		let txt = "";
		let { RI } = fields
		if (RI) {
			txt += `;RI=${data[RI] || 'U'}`
		}
		return txt;
	} catch (e) {
		console.error(e)
		return ""
	}
}

// Technoton Fuel
export function getFF(fields, data) {
	try {
		let txt = "";
		if ( (fields['$fuel'] != undefined) && (data["$fuel.connected"] != undefined) ) {
			const connected = ( data["$fuel.connected"] ) ? '1' : '0';
			txt += `;FF=${connected},${data["$fuel.frequency"]},${data["$fuel.temperature"]},${data["$fuel.level"]}`;
		}
		return txt;

	} catch (error) {
		console.error(error);
		return "";
	}
}

export function getBLE(fields, data) {
	try {
		let txt = "";
		//console.log("getBLE:", fields, data);
		if (data['$ble.list'] != '' && data['$ble.list'] != undefined ) {   //fields['$ble'] == '$ble' && 
			txt += `;BBS=`;
			let devices = data['$ble.list'].split(',');
			devices.forEach(key => {
				if (key.length >= 12) {
					txt += `${data[`$ble.${key}.tag`]},`;
				} else {
					// txt += `,`;
				}
										
			});	

			// Remove last character if neded
			if (txt.charAt(txt.length-1) == ',') {
				txt = txt.slice(0,-1);
			}
			//console.log('TAG:', txt);
		}
		return txt;
	} catch (error) {
		console.error(error);
		return "";
	}
}
